#[non_exhaustive]pub enum OwnedError {
BuildNoPrefix,
Internal(u32),
NoPrefix(String, String),
NoSuffix(String, String),
NoVDot(String),
TableNoChild(String),
TableNotTable,
TomlBoml(String),
TwoComponentsExpected(String),
UIntExpected(String, String, ParseIntError),
}Expand description
An equivalent to Error that owns the error parameters.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BuildNoPrefix
No prefix specified for the config builder.
Internal(u32)
Something went really, really wrong…
NoPrefix(String, String)
The media type did not have the specified prefix.
NoSuffix(String, String)
The media type did not have the specified suffix.
NoVDot(String)
The media type did not have the “.v” part.
TableNoChild(String)
The hierarchical structure did not contain the specified element.
TableNotTable
The hierarchical structure did not contain the expected table or string.
TomlBoml(String)
Could not parse a TOML document.
TwoComponentsExpected(String)
The media type’s version part did not consist of two dot-separated components.
UIntExpected(String, String, ParseIntError)
The media type contained an invalid version component.