#[non_exhaustive]pub enum Error<'data> {
BuildNoPrefix,
Internal(u32),
NoPrefix(&'data str, &'data str),
NoSuffix(&'data str, &'data str),
NoVDot(&'data str),
TwoComponentsExpected(&'data str),
UIntExpected(&'data str, &'data str, ParseIntError),
}Expand description
An error that occurred while processing the media type string.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BuildNoPrefix
No prefix specified for the config builder.
Internal(u32)
Something went really wrong.
NoPrefix(&'data str, &'data str)
The media type did not have the specified prefix.
NoSuffix(&'data str, &'data str)
The media type did not have the specified suffix.
NoVDot(&'data str)
The media type did not have the “.v” part.
TwoComponentsExpected(&'data str)
The media type’s version part did not consist of two dot-separated components.
UIntExpected(&'data str, &'data str, ParseIntError)
The media type contained an invalid version component.